@@ -102,12 +102,19 @@ void MainWindow::onTick() {
 
 void MainWindow::timerEvent(QTimerEvent *event) {
 	if (tickTimer == event->timerId()) {
-		ticks++;
+            ticks++;
 
-		QFont font;
-        font.setPointSize( (ticks % 40) + 36);
-        ui->operation->setFont(font);
-		return;
+            QFont font;
+            font.setPointSize( (ticks % 40) + 36);
+            ui->operation->setFont(font);
+            ui->label_1_1->setFont(font);
+            ui->label_1_0->setFont(font);
+            ui->label_0_1->setFont(font);
+            ui->label_0_0->setFont(font);
+            ui->result1->setFont(font);
+            ui->result0->setFont(font);
+
+            return;
 	}
 
 	if (animTimer != event->timerId())
