@@ -5,6 +5,8 @@
 #include <QtGui>
 #include "randomnumbers.h"
 
+#define VERSION "0.1"
+
 namespace Ui {
     class MainWindow;
 }
@@ -23,9 +25,11 @@ private:
 
     Item * currentItem;
     RandomNumbers * numbers;
-    QTimer * timer;
+    //QTimer * timer;
 
-    int ticks;
+    void paintEvent(QPaintEvent* event);
+
+    int ticks, fails;
     int number1;
     int number0;
     int result;
@@ -34,6 +38,10 @@ private:
 
     QString current;
 
+    int anim, animTimer;
+    int tickTimer;
+    bool showImage, wasOk;
+
     void set (char c);
     void confirm ();
     void think ();
@@ -46,10 +54,16 @@ private:
     void showResult(int n);
     void showOperation(int n);
 
+protected:
+    void timerEvent(QTimerEvent *event);
+
 private slots:
 
 	void onTick ();
     void options ();
+    void about ();
+    void donate ();
+    void listenInactivity(QString s);
     void on_pushButton1_clicked();
     void on_pushButton0_clicked();
     void on_pushButton2_clicked();
