@@ -199,16 +199,16 @@ void RandomNumbers::update (Item * it, int failures, int time) {
     if (failures <= 0) {
     	// TODO time
 
-        for (int i = 0; i < numbers.length(); i++) {
-            Item * tmp = numbers.at(i);
-            if (tmp != it) {
-                tmp->frec++;
+//        for (int i = 0; i < numbers.length(); i++) {
+//            Item * tmp = numbers.at(i);
+//            if (tmp != it) {
+//                tmp->frec++;
 
-				QString n = QString ("STATS/%1-%2-%3/M/%4").arg(tmp->num1).arg(tmp->operation).arg(tmp->num0).arg(tmp->mode);
-				settings.setValue(n, (int)tmp->frec);
+//				QString n = QString ("STATS/%1-%2-%3/M/%4").arg(tmp->num1).arg(tmp->operation).arg(tmp->num0).arg(tmp->mode);
+//				settings.setValue(n, (int)tmp->frec);
 
-            }
-        }
+//            }
+//        }
     }
     else {
     	// TODO failures & time
